@@ -36,15 +36,15 @@ class Authorizer(abc.ABC):
 
 class TokenAuthorizer(Authorizer):
 
+    def __init__(self, token_manager: TokenManager):
+        self._token_manager: TokenManager = token_manager
+
     @property
-    @abc.abstractmethod
-    def token_manager(self) -> Optional[TokenManager]:
-        pass
+    def token_manager(self) -> TokenManager:
+        return self._token_manager
 
     def authorize(self, request: Any, context: Any, access_level: AccessLevel, user_role: Optional[UserRole],
                   validation_object_type: ValidationObjectType):
-        if self.token_manager is None:
-            raise RuntimeError("Token manager is not set")
         project_id = getattr_short_circuit(request, ['project_id', 'project'])
         scenario_id = getattr_short_circuit(request, ['scenario_id', 'scenario'])
         prefix = getattr(request, 'prefix', None)
@@ -92,9 +92,10 @@ def authorize_grpc_stream(
                     try:
                         servicer.authorize(request, context, access_level, user_role, validation_object_type)
                     except ValidationFailedError as e:
+                        user_role_name = user_role.name if user_role else None
                         log.info('Could not authorize token for stream %s, AccessLevel=%s, UserRole=%s, '
-                                 'ValidationObjectType=%s - %s', method.__qualname__, access_level.name, user_role.name,
-                                 validation_object_type.name, user_role.name, e.msg)
+                                 'ValidationObjectType=%s - %s', method.__qualname__, access_level.name, user_role_name,
+                                 validation_object_type.name, user_role_name, e.msg)
                         raise
                     yield request
 
